import React, {
  useState,
  useCallback,
  useEffect,
} from 'react';
import ReactDOM from 'react-dom';
import { sleepData } from './useData';
import { scaleBand, scaleLinear, max } from 'd3';

const width = window.innerWidth;
const height = window.innerHeight;
const margin = { top: 20, left: 75, bottom: 20, right: 20 };
const innerHeight = height - margin.top - margin.bottom;
const innerWidth = width - margin.left - margin.right;

const App = () => {
  const data = sleepData(innerHeight);
  if (!data) {
    return <pre> Loading . . . </pre>;
  }
  console.log('KMS is there data??: ', data);

  const xAxisLabel = 'Phase of the Moon';
  const xScale = scaleBand()
    .domain(data.map((d) => d['moonPhase']))
    .range([0, innerWidth])
    .paddingInner(0.12);

  const yAxisLabel = 'Time Asleep and Duration';
  const yScale = scaleLinear()
    .domain([-6, max(data.map((d) => d['endHour']))])
    .range([innerHeight - margin.bottom, margin.top]);

  return (
    <svg width={width} height={height}>
      <g
        transform={`translate(${margin.left}, ${margin.top})`}
      >
        {yScale.ticks(18).map((tickValue) => (
          <g
            transform={`translate(0, ${yScale(tickValue)})`}
          >
            <line x2={innerWidth} stroke="#bbb" />
            <text dx="-2em">{tickValue}</text>
          </g>
        ))}
        {xScale.domain().map((tickValue) => (
          <text
            key={tickValue}
            y={innerHeight + 20}
            x={xScale(tickValue)}
          >
            {tickValue}
          </text>
        ))}
        {data.map((d) => (
          <rect
            className="mark"
            key={d['dateOfSleep']}
            x={xScale(d['calendarDayNumberOfSleep'])}
            y={yScale(d.endHour)}
            width={xScale.bandwidth()}
            height={yScale(d['decHoursAsleep'])}
          />
        ))}
      </g>
    </svg>
  );
};

const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);

/* 
{yScale.ticks().map((tickValue) => (
          <g transform={`translate(0, ${yScale(tickValue)})`}>
          <line
            x2={innerWidth}
            stroke="#bbb"
          />
            <text dx="-2em">{tickValue}</text>
          </g> -->
        ))}
*/
